==> langstream-0.1.5.tar.gz: langstream-0.1.5/setup.py <==
from setuptools import setup, find_packages

with open("requirements.txt") as f:
    requirements = f.read().splitlines()

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="langstream",
    version="0.1.5",
    packages=find_packages(),
    install_requires=requirements,
    author="Rogerio Chaves",
    author_email="rogeriocfj@gmail.com",
    description="Build robust LLM applications with true composability 🔗",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="MIT",
    keywords="chain llm ai stream functional programming",
    url="https://github.com/rogeriochaves/litechain",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    python_requires=">=3.6",
    project_urls={
        "Documentation": "https://rogeriochaves.github.io/litechain/",
        "Source Code": "https://github.com/rogeriochaves/litechain",
        "Issue Tracker": "https://github.com/rogeriochaves/litechain/issues",
    },
    include_package_data=True,
)

==> langstream-0.1.7.tar.gz: langstream-0.1.7/setup.py <==
from setuptools import setup, find_packages

with open("requirements.txt") as f:
    requirements = f.read().splitlines()

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="langstream",
    version="0.1.7",
    packages=find_packages(),
    install_requires=requirements,
    author="Rogerio Chaves",
    author_email="rogeriocfj@gmail.com",
    description="Build robust LLM applications with true composability 🔗",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="MIT",
    keywords="stream llm ai stream functional programming",
    url="https://github.com/rogeriochaves/langstream",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    python_requires=">=3.6",
    project_urls={
        "Documentation": "https://rogeriochaves.github.io/langstream/",
        "Source Code": "https://github.com/rogeriochaves/langstream",
        "Issue Tracker": "https://github.com/rogeriochaves/langstream/issues",
    },
    include_package_data=True,
)
